# libpythonpro
Modulo para exemplificar a construçao de projetos no curso Pytools

Para instalar

"""console
python -m venv .venv
source .ven/bin/activate
pip install -r requirements-dev.txt"""

Para conferir qualidade do codigo:

'''console
flake8
'''